@@ -1,2 +1,2 @@
 from .model_views import *
-from .func_views import *
+#from .func_views import *
